@@ -13,8 +13,9 @@
 #' @example examples/geom_crossbar_interactive.R
 #' @seealso [girafe()]
 #' @export
-geom_crossbar_interactive <- function(...)
+geom_crossbar_interactive <- function(...) {
   layer_interactive(geom_crossbar, ...)
+}
 
 #' @rdname ggiraph-ggproto
 #' @format NULL
@@ -26,25 +27,37 @@ GeomInteractiveCrossbar <- ggproto(
   default_aes = add_default_interactive_aes(GeomCrossbar),
   parameters = interactive_geom_parameters,
   draw_key = interactive_geom_draw_key,
-  draw_panel = function(data,
-                        panel_params,
-                        coord,
-                        lineend = "butt",
-                        linejoin = "mitre",
-                        fatten = 2.5,
-                        width = NULL,
-                        flipped_aes = FALSE,
-                        .ipar = IPAR_NAMES) {
+  draw_panel = function(
+    data,
+    panel_params,
+    coord,
+    lineend = "butt",
+    linejoin = "mitre",
+    fatten = 2.5,
+    width = NULL,
+    flipped_aes = FALSE,
+    .ipar = IPAR_NAMES
+  ) {
     data <- flip_data(data, flipped_aes)
 
-    middle <- transform(data, x = xmin, xend = xmax, yend = y, linewidth = linewidth * fatten, alpha = NA)
+    middle <- transform(
+      data,
+      x = xmin,
+      xend = xmax,
+      yend = y,
+      linewidth = linewidth * fatten,
+      alpha = NA
+    )
 
-    has_notch <- !is.null(data$ynotchlower) && !is.null(data$ynotchupper) &&
-      !is.na(data$ynotchlower) && !is.na(data$ynotchupper)
+    has_notch <- !is.null(data$ynotchlower) &&
+      !is.null(data$ynotchupper) &&
+      !is.na(data$ynotchlower) &&
+      !is.na(data$ynotchupper)
 
     if (has_notch) {
-      if (data$ynotchlower < data$ymin  ||  data$ynotchupper > data$ymax)
+      if (data$ynotchlower < data$ymin || data$ynotchupper > data$ymax) {
         message("notch went outside hinges. Try setting notch=FALSE.")
+      }
 
       notchindent <- (1 - data$notchwidth) * (data$xmax - data$xmin) / 2
 
@@ -53,13 +66,29 @@ GeomInteractiveCrossbar <- ggproto(
 
       box <- data_frame0(
         x = c(
-          data$xmin, data$xmin, data$xmin + notchindent, data$xmin, data$xmin,
-          data$xmax, data$xmax, data$xmax - notchindent, data$xmax, data$xmax,
+          data$xmin,
+          data$xmin,
+          data$xmin + notchindent,
+          data$xmin,
+          data$xmin,
+          data$xmax,
+          data$xmax,
+          data$xmax - notchindent,
+          data$xmax,
+          data$xmax,
           data$xmin
         ),
         y = c(
-          data$ymax, data$ynotchupper, data$y, data$ynotchlower, data$ymin,
-          data$ymin, data$ynotchlower, data$y, data$ynotchupper, data$ymax,
+          data$ymax,
+          data$ynotchupper,
+          data$y,
+          data$ynotchlower,
+          data$ymin,
+          data$ymin,
+          data$ynotchlower,
+          data$y,
+          data$ynotchupper,
+          data$ymax,
           data$ymax
         ),
         alpha = rep(data$alpha, 11),
@@ -70,7 +99,6 @@ GeomInteractiveCrossbar <- ggproto(
         group = rep(seq_len(nrow(data)), 11)
       )
       box <- copy_interactive_attrs(data, box, 11, ipar = .ipar)
-
     } else {
       # No notch
       box <- data_frame0(
@@ -88,11 +116,28 @@ GeomInteractiveCrossbar <- ggproto(
     box <- flip_data(box, flipped_aes)
     middle <- flip_data(middle, flipped_aes)
 
-    ggname("geom_interactive_crossbar", gTree(
-      children = gList(
-        GeomInteractivePolygon$draw_panel(box, panel_params, coord, lineend = lineend, linejoin = linejoin, .ipar = .ipar),
-        GeomInteractiveSegment$draw_panel(middle, panel_params, coord, lineend = lineend, linejoin = linejoin, .ipar = .ipar)
+    ggname(
+      "geom_interactive_crossbar",
+      gTree(
+        children = gList(
+          GeomInteractivePolygon$draw_panel(
+            box,
+            panel_params,
+            coord,
+            lineend = lineend,
+            linejoin = linejoin,
+            .ipar = .ipar
+          ),
+          GeomInteractiveSegment$draw_panel(
+            middle,
+            panel_params,
+            coord,
+            lineend = lineend,
+            linejoin = linejoin,
+            .ipar = .ipar
+          )
+        )
       )
-    ))
+    )
   }
 )
