@@ -1,10 +1,12 @@
 #' Calls a base grid grob function and returns an interactive grob.
 #' @noRd
-grob_interactive <- function(grob_func,
-                             ...,
-                             cl = NULL,
-                             data_attr = "data-id",
-                             extra_interactive_params = NULL) {
+grob_interactive <- function(
+  grob_func,
+  ...,
+  cl = NULL,
+  data_attr = "data-id",
+  extra_interactive_params = NULL
+) {
   args <- list(...)
   # We need to get the interactive parameters from the arguments and remove them
   ipar <- get_default_ipar(extra_interactive_params)
