@@ -7,8 +7,6 @@ class a_color {
 public:
   a_color (int);
   bool is_visible();
-  bool is_transparent();
-  bool has_alpha();
   std::string color();
   std::string opacity();
 
